HomeDirectoryMapEntry class

Represents an object that contains entries and targets for HomeDirectoryMappings.

Constructors

HomeDirectoryMapEntry({required String entry, required String target})
HomeDirectoryMapEntry.fromJson(Map<String, dynamic> json)
factory

Properties

entry → String
Represents an entry and a target for HomeDirectoryMappings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String
Represents the map target that is used in a HomeDirectorymapEntry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited